@@ -15,7 +15,7 @@
  * and usb.c, keeping the common protocols/busses support in this
  * file.
  *
- * $Id: canon.c,v 1.210.2.1 2003/07/26 13:06:48 hun Exp $
+ * $Id: canon.c,v 1.227 2003/10/10 10:54:32 marcusmeissner Exp $
  */
 
 #include "config.h"
@@ -94,78 +94,92 @@
 
 const struct canonCamModelData models[] = {
 	/* *INDENT-OFF* */
-	{"Canon:PowerShot A5",	        CANON_PS_A5,		NO_USB, NO_USB, CAP_NON,  S2M, S32K, "DE300 Canon Inc."},
-	{"Canon:PowerShot A5 Zoom",	CANON_PS_A5_ZOOM,	NO_USB, NO_USB, CAP_NON,  S2M, S32K, "Canon PowerShot A5 Zoom"},
-	{"Canon:PowerShot A50",		CANON_PS_A50,		NO_USB, NO_USB, CAP_NON,  S2M, S32K, "Canon PowerShot A50"},
-	{"Canon:PowerShot Pro70",	CANON_PS_PRO70,		NO_USB, NO_USB, CAP_NON,  S2M, S32K, "Canon PowerShot Pro70"},
-	{"Canon:PowerShot S10",		CANON_PS_S10,		0x04A9, 0x3041, CAP_NON, S10M, S32K, "Canon PowerShot S10"},
-	{"Canon:PowerShot S20",		CANON_PS_S20,		0x04A9, 0x3043, CAP_NON, S10M, S32K, "Canon PowerShot S20"},
-	{"Canon:EOS D30",		CANON_EOS_D30,		0x04A9, 0x3044, CAP_SUP, S10M, S32K, NULL},
-	{"Canon:PowerShot S100",	CANON_PS_S100,		0x04A9, 0x3045, CAP_NON, S10M, S32K, NULL},
-	{"Canon:IXY DIGITAL",		CANON_PS_S100,		0x04A9, 0x3046, CAP_NON, S10M, S32K, NULL},
-	{"Canon:Digital IXUS",		CANON_PS_S100,		0x04A9, 0x3047, CAP_NON, S10M, S32K, NULL},
-	{"Canon:PowerShot G1",		CANON_PS_G1,		0x04A9, 0x3048, CAP_SUP, S10M, S32K, "Canon PowerShot G1"},
-	{"Canon:PowerShot Pro90 IS",	CANON_PS_PRO90_IS,	0x04A9, 0x3049, CAP_SUP, S10M, S32K, "Canon PowerShot Pro90 IS"},
-	{"Canon:IXY DIGITAL 300",	CANON_PS_S300,		0x04A9, 0x304B, CAP_SUP, S10M, S32K, NULL},
-	{"Canon:PowerShot S300",	CANON_PS_S300,		0x04A9, 0x304C, CAP_SUP, S10M, S32K, NULL},
-	{"Canon:Digital IXUS 300",	CANON_PS_S300,		0x04A9, 0x304D, CAP_SUP, S10M, S32K, NULL},
-	{"Canon:PowerShot A20",		CANON_PS_A20,		0x04A9, 0x304E, CAP_SUP, S10M, S32K, NULL},
-	{"Canon:PowerShot A10",		CANON_PS_A10,		0x04A9, 0x304F, CAP_SUP, S10M, S32K, NULL},
-	/* Mac OS includes this as a valid ID; don't know which camera model --swestin */
-	/*{"Canon:PowerShot ??",		CANON_PS_A10,		0x04A9, 0x3050, CAP_SUP, S10M, S32K, NULL},*/
-	/* Canon IXY DIGITAL 200 here? */
-	{"Canon:PowerShot S110",	CANON_PS_S100,		0x04A9, 0x3051, CAP_SUP, S10M, S32K, NULL},
-	{"Canon:DIGITAL IXUS v",	CANON_PS_S100,		0x04A9, 0x3052, CAP_SUP, S10M, S32K, NULL},
-	{"Canon:PowerShot G2",		CANON_PS_G2,		0x04A9, 0x3055, CAP_SUP, S10M, S32K, NULL},
-	{"Canon:PowerShot S40",		CANON_PS_S40,		0x04A9, 0x3056, CAP_SUP, S10M, S32K, NULL},
-	{"Canon:PowerShot S30",		CANON_PS_S30,		0x04A9, 0x3057, CAP_SUP, S10M, S32K, NULL},
-	{"Canon:PowerShot A40",		CANON_PS_A40,		0x04A9, 0x3058, CAP_SUP, S10M, S32K, NULL},
-	{"Canon:PowerShot A30",		CANON_PS_A30,		0x04A9,	0x3059, CAP_SUP, S10M, S32K, NULL},
-	/* 305c is in MacOS Info.plist, but I don't know what it is --swestin. */
-	/*{"Canon:PowerShot ????",		CANON_PS_A30,		0x04A9,	0x305c, CAP_SUP, S10M, S32K, NULL},*/
-	{"Canon:EOS D60",		CANON_EOS_D60,		0x04A9, 0x3060, CAP_SUP, S10M, S32K, NULL},
-	{"Canon:PowerShot A100",	CANON_PS_A100,		0x04A9, 0x3061, CAP_SUP, S10M, S32K, NULL},
-	{"Canon:PowerShot A200",	CANON_PS_A200,		0x04A9, 0x3062, CAP_SUP, S10M, S32K, NULL},
-	{"Canon:PowerShot A300",	CANON_PS_A300,		0x04A9, 0x3076, CAP_SUP, S10M, S32K, NULL},
-	{"Canon:PowerShot S200",	CANON_PS_S200,		0x04A9, 0x3065, CAP_SUP, S10M, S32K, NULL},
-	{"Canon:Digital IXUS v2",	CANON_PS_S200,		0x04A9, 0x3065, CAP_SUP, S10M, S32K, NULL},
-	{"Canon:Digital IXUS 330",	CANON_PS_S330,		0x04A9, 0x3066, CAP_SUP, S10M, S32K, NULL},
-	{"Canon:PowerShot S50 (normal mode)",	CANON_PS_S50,	0x04A9, 0x3077, CAP_SUP, S99M, S32K, NULL},
-	{"Canon:PowerShot S45 (normal mode)",	CANON_PS_S45,	0x04A9, 0x306C, CAP_SUP, S99M, S32K, NULL},
-	/* 306a is in MacOS Info.plist, but I don't know what it is --swestin. */
-	/*{"Canon:Digital ???",	CANON_PS_??,		0x04A9, 0x3066, CAP_SUP, S10M, S32K, NULL},*/
-	{"Canon:PowerShot S45 (normal mode)",	CANON_PS_S45,	0x04A9, 0x306a, CAP_SUP, S99M, S32K, NULL},
-        /* 0x306D is S45 in PTP mode */
-	{"Canon:PowerShot G3 (normal mode)",	CANON_PS_G3,	0x04A9, 0x306E, CAP_SUP, S99M, S32K, NULL},
-        /* 0x306F is G3 in PTP mode */
-	{"Canon:PowerShot S230 (normal mode)",	CANON_PS_S230,	0x04A9, 0x3070, CAP_SUP, S99M, S32K, NULL},
-        /* 0x3071 is S230 in PTP mode */
-	{"Canon:Digital IXUS v3 (normal mode)",	CANON_PS_S230,	0x04A9, 0x3070, CAP_SUP, S99M, S32K, NULL},
-        /* 0x3071 is IXUS v3 in PTP mode */
-	/* reported working on SourceForge patch tracker. */
-	/* FIXME: dunno about capture, assuming none for now -Marcus */
-	{"Canon:Digital IXUS 400",              CANON_PS_S230,  0x04A9, 0x3075, CAP_SUP, S99M, S32K, NULL},
-	{"Canon:PowerShot S400",                CANON_PS_S230,  0x04A9, 0x3075, CAP_SUP, S99M, S32K, NULL},
+	{"Canon:PowerShot A5",	        CANON_PS_A5,		NO_USB, NO_USB, CAP_NON,  S2M, S32K, S2M, "DE300 Canon Inc."},
+	{"Canon:PowerShot A5 Zoom",	CANON_PS_A5_ZOOM,	NO_USB, NO_USB, CAP_NON,  S2M, S32K, S2M, "Canon PowerShot A5 Zoom"},
+	{"Canon:PowerShot A50",		CANON_PS_A50,		NO_USB, NO_USB, CAP_NON,  S2M, S32K, S2M, "Canon PowerShot A50"},
+	{"Canon:PowerShot Pro70",	CANON_PS_PRO70,		NO_USB, NO_USB, CAP_NON,  S2M, S32K, S2M, "Canon PowerShot Pro70"},
+	{"Canon:PowerShot S10",		CANON_PS_S10,		0x04A9, 0x3041, CAP_NON, S10M, S32K, S2M, "Canon PowerShot S10"},
 
+	{"Canon:PowerShot S20",		CANON_PS_S20,		0x04A9, 0x3043, CAP_NON, S10M, S32K, S2M, "Canon PowerShot S20"},
+	{"Canon:EOS D30",		CANON_EOS_D30,		0x04A9, 0x3044, CAP_SUP, S10M, S32K, S2M, NULL},
+	{"Canon:PowerShot S100",	CANON_PS_S100,		0x04A9, 0x3045, CAP_NON, S10M, S32K, S2M, NULL},
+	{"Canon:IXY DIGITAL",		CANON_PS_S100,		0x04A9, 0x3046, CAP_NON, S10M, S32K, S2M, NULL},
+	{"Canon:Digital IXUS",		CANON_PS_S100,		0x04A9, 0x3047, CAP_NON, S10M, S32K, S2M, NULL},
+	{"Canon:PowerShot G1",		CANON_PS_G1,		0x04A9, 0x3048, CAP_SUP, S10M, S32K, S2M, "Canon PowerShot G1"},
+	{"Canon:PowerShot Pro90 IS",	CANON_PS_PRO90_IS,	0x04A9, 0x3049, CAP_SUP, S10M, S32K, S2M, "Canon PowerShot Pro90 IS"},
+
+	{"Canon:IXY DIGITAL 300",	CANON_PS_S300,		0x04A9, 0x304B, CAP_SUP, S10M, S32K, S2M, NULL},
+	{"Canon:PowerShot S300",	CANON_PS_S300,		0x04A9, 0x304C, CAP_SUP, S10M, S32K, S2M, NULL},
+	{"Canon:Digital IXUS 300",	CANON_PS_S300,		0x04A9, 0x304D, CAP_SUP, S10M, S32K, S2M, NULL},
+	{"Canon:PowerShot A20",		CANON_PS_A20,		0x04A9, 0x304E, CAP_SUP, S10M, S32K, S2M, NULL},
+	{"Canon:PowerShot A10",		CANON_PS_A10,		0x04A9, 0x304F, CAP_SUP, S10M, S32K, S2M, NULL},
+	/* Mac OS includes this as a valid ID; don't know which camera model --swestin */
+	{"Canon:PowerShot unknown 1",	CANON_PS_UNK1,		0x04A9, 0x3050, CAP_SUP, S10M, S32K, S2M, NULL},
+	/* Canon IXY DIGITAL 200 here? */
+	{"Canon:PowerShot S110",	CANON_PS_S100,		0x04A9, 0x3051, CAP_SUP, S10M, S32K, S2M, NULL},
+	{"Canon:DIGITAL IXUS v",	CANON_PS_S100,		0x04A9, 0x3052, CAP_SUP, S10M, S32K, S2M, NULL},
+
+	{"Canon:PowerShot G2",		CANON_PS_G2,		0x04A9, 0x3055, CAP_SUP, S10M, S32K, S2M, NULL},
+	{"Canon:PowerShot S40",		CANON_PS_S40,		0x04A9, 0x3056, CAP_SUP, S10M, S32K, S2M, NULL},
+	{"Canon:PowerShot S30",		CANON_PS_S30,		0x04A9, 0x3057, CAP_SUP, S10M, S32K, S2M, NULL},
+	{"Canon:PowerShot A40",		CANON_PS_A40,		0x04A9, 0x3058, CAP_SUP, S10M, S32K, S2M, NULL},
+	{"Canon:PowerShot A30",		CANON_PS_A30,		0x04A9,	0x3059, CAP_SUP, S10M, S32K, S2M, NULL},
+
+	/* 305c is in MacOS Info.plist, but I don't know what it is --swestin. */
+	{"Canon:PowerShot unknown 2",	CANON_PS_UNK2,		0x04A9,	0x305c, CAP_SUP, S10M, S32K, S2M, NULL},
+
+	{"Canon:EOS D60",		CANON_EOS_D60,		0x04A9, 0x3060, CAP_SUP, S10M, S32K, S2M, NULL},
+	{"Canon:PowerShot A100",	CANON_PS_A100,		0x04A9, 0x3061, CAP_SUP, S10M, S32K, S2M, NULL},
+	{"Canon:PowerShot A200",	CANON_PS_A200,		0x04A9, 0x3062, CAP_SUP, S10M, S32K, S2M, NULL},
+
+	{"Canon:PowerShot S200",	CANON_PS_S200,		0x04A9, 0x3065, CAP_SUP, S10M, S32K, S2M, NULL},
+	{"Canon:Digital IXUS v2",	CANON_PS_S200,		0x04A9, 0x3065, CAP_SUP, S10M, S32K, S2M, NULL},
+	{"Canon:Digital IXUS 330",	CANON_PS_S330,		0x04A9, 0x3066, CAP_SUP, S10M, S32K, S2M, NULL},
+	/* Canon MVX2i in some mode is 0x3067 - probably PTP */
+
+	/* 306a is in MacOS Info.plist, but I don't know what it is --swestin. */
+	{"Canon:Digital unknown 3",	CANON_PS_UNK3,		0x04A9, 0x306a, CAP_SUP, S10M, S32K, S2M, NULL},
+	/* Apparently the MVX2i is the same as Optura 200 MC (Philippe
+	 * Gramoulle), so share the code. */
+	{"Canon:MVX2i",			CANON_OPT_200,		0x04A9, 0x306B, CAP_SUP, S99M, S32K, S2M, NULL},
+	{"Canon:Optura 200 MC",		CANON_OPT_200,		0x04A9, 0x306B, CAP_SUP, S99M, S32K, S2M, NULL},
+	{"Canon:PowerShot S45 (normal mode)",	CANON_PS_S45,	0x04A9, 0x306C, CAP_SUP, S99M, S32K, S2M, NULL},
+        /* 0x306D is S45 in PTP mode */
+	{"Canon:PowerShot G3 (normal mode)",	CANON_PS_G3,	0x04A9, 0x306E, CAP_SUP, S99M, S32K, S2M, NULL},
+        /* 0x306F is G3 in PTP mode */
+	{"Canon:PowerShot S230 (normal mode)",	CANON_PS_S230,	0x04A9, 0x3070, CAP_SUP, S99M, S32K, S2M, NULL},
+	{"Canon:Digital IXUS v3 (normal mode)",	CANON_PS_S230,	0x04A9, 0x3070, CAP_SUP, S99M, S32K, S2M, NULL},
+        /* 0x3071 is S230/IXUS v3 in PTP mode */
+
+	{"Canon:PowerShot SD100 (normal mode)",	CANON_PS_SD100,	0x04A9, 0x3072, CAP_SUP, S99M, S32K, S2M, NULL},
+	{"Canon:Digital IXUS II (normal mode)",	CANON_PS_SD100,	0x04A9, 0x3072, CAP_SUP, S99M, S32K, S2M, NULL},
 	/* added from report on mailinglist. XXX: assuming capture works -Marcus */
 	/* reports suggest that they provide 1 interface which does
 	 * both PTP and Canon access modes.
 	 */
-	{"Canon:PowerShot A60",         CANON_PS_A60,           0x04A9, 0x3074, CAP_SUP,  S99M, S32K},
-	{"Canon:PowerShot A70",         CANON_PS_A70,           0x04A9, 0x3073, CAP_SUP,  S99M, S32K},
+	{"Canon:PowerShot A70",         CANON_PS_A70,           0x04A9, 0x3073, CAP_SUP, S99M, S32K, S2M, NULL},
+	{"Canon:PowerShot A60",         CANON_PS_A60,           0x04A9, 0x3074, CAP_SUP, S99M, S32K, S2M, NULL},
+	/* reported working on SourceForge patch tracker. */
+	/* S400 product ID is 0x3075; this responds both to Canon
+	 * protocol and PTP. */
+	{"Canon:Digital IXUS 400",      CANON_PS_S400,		0x04A9, 0x3075, CAP_SUP, S99M, S32K, S2M, NULL},
+	{"Canon:PowerShot S400",        CANON_PS_S400,		0x04A9, 0x3075, CAP_SUP, S99M, S32K, S2M, NULL},
 
-	/* S400 product ID for PTP mode is 0x3075; there may be no
-	 * "Canon" mode, so it will be supported by the PTP driver,
-	 * not here. */
 	/* 3078 and 307a are in MacOS Info.plist, but I don't know
 	 * what they are --swestin. */
-	/*{"Canon:PowerShot ?????",		CANON_PS_A60,		0x04A9, 0x3078, CAP_SUP, S10M, S32K, NULL},*/
-	/*{"Canon:PowerShot ?????",		CANON_PS_A60,		0x04A9, 0x307a, CAP_SUP, S10M, S32K, NULL},*/
-	{"Canon:EOS 10D",		CANON_EOS_10D,		0x04A9, 0x3083, CAP_SUP, S10M, S32K, NULL},
-	/* Canon MVX2i in some mode is 0x3067 - probably PTP */
-	/* Apparently the MVX2i is the same as Optura 200 MC (Philippe
-	 * Gramoulle), so share the code. */
-	{"Canon:Optura 200 MC",		CANON_OPT_200,		0x04A9, 0x306B, CAP_SUP, S99M, S32K, NULL},
+	{"Canon:PowerShot unknown 4",		CANON_PS_UNK4,	0x04A9, 0x3078, CAP_SUP, S10M, S32K, S2M, NULL},
+
+	{"Canon:PowerShot unknown 5",		CANON_PS_UNK5,	0x04A9, 0x307a, CAP_SUP, S10M, S32K, S2M, NULL},
+	/* MV630i seems to be a DV camcorder */
+	{"Canon:MV630i",		CANON_MV630I,		0x04A9, 0x307b, CAP_SUP, S99M, S32K, S2M, NULL},
+
+	{"Canon:EOS 10D",		CANON_EOS_10D,		0x04A9, 0x3083, CAP_SUP, S10M, S32K, S2M, NULL},
+	/* 0x3099 is the EOS 300D/Digital Rebel in PTP mode */
+	{"Canon:EOS 300D (normal mode)",	CANON_EOS_300D, 0x04A9, 0x3084, CAP_SUP, S10M, S32K, S2M, NULL},
+	{"Canon:EOS Digital Rebel (normal mode)",CANON_EOS_300D,0x04A9, 0x3084, CAP_SUP, S10M, S32K, S2M, NULL},
+	{"Canon:EOS Kiss Digital (normal mode)",CANON_EOS_300D, 0x04A9, 0x3084, CAP_SUP, S10M, S32K, S2M, NULL},
+	{"Canon:PowerShot A80 (normal mode)",CANON_PS_A80,      0x04A9, 0x309A, CAP_SUP,  S99M, S32K, S2M, NULL},
+
 	{NULL}
 	/* *INDENT-ON* */
 };
@@ -228,6 +242,48 @@ replace_filename_extension(const char *filename, const char *newext)
 	}
 }
 
+static char *
+filename_to_audio(const char *filename, const char *newext)
+{
+	char *p;
+	static char buf[1024];
+
+	/* We just replace file ending by .WAV, the first three
+	 * letters by SND and assume this is the name of the audio file.
+	 */
+	if (strncpy (buf, filename, sizeof (buf)) < 0) {
+		GP_DEBUG ("filename_to_audio: Buffer too small in %s line %i.",
+			  __FILE__, __LINE__);
+		return NULL;
+	}
+	if ((p = strrchr (buf, '_')) == NULL) {
+		GP_DEBUG ("filename_to_audio: No '.' found in filename '%s' "
+			  "in %s line %i.", filename, __FILE__, __LINE__);
+		return NULL;
+	}
+	if ((p - buf) > 3) {
+		p -= 3;
+		p[0] = 'S';
+		p[1] = 'N';
+		p[2] = 'D';
+	}
+	if ((p = strrchr (buf, '.')) == NULL) {
+		GP_DEBUG ("filename_to_audio: No '.' found in filename '%s' "
+			  "in %s line %i.", filename, __FILE__, __LINE__);
+		return NULL;
+	}
+	if (((p - buf) < sizeof (buf) - 4) && strncpy (p, ".WAV", 4)) {
+		GP_DEBUG ("filename_to_audio: New name for '%s' is '%s'",
+			  filename, buf);
+		return buf;
+	} else {
+		GP_DEBUG ("filename_to_audio: "
+			  "New name for filename '%s' doesnt fit in %s line %i.",
+			  filename, __FILE__, __LINE__);
+		return NULL;
+	}
+}
+
 /**
  * canon_int_filename2audioname:
  * @camera: Camera to work on
@@ -244,11 +300,17 @@ replace_filename_extension(const char *filename, const char *newext)
 const char *
 canon_int_filename2audioname (Camera *camera, const char *filename)
 {
-        /* FIXME: I want capabilities */
+	char *result;
+
+	/* FIXME: I want capabilities */
+	/* FIXME: Do we really have to check the model here? Someone
+	 * could just have inserted the CF card into another camera...
+	 * */
 	switch (camera->pl->md->model) {
 	case CANON_PS_S30:
 	case CANON_PS_S40:
 	case CANON_PS_S45:
+	case CANON_PS_S400:
 	case CANON_PS_G3:
 		break;
 	default:
@@ -259,7 +321,7 @@ canon_int_filename2audioname (Camera *camera, const char *filename)
 	}
 
 	/* We use the audio file itself as the audio file of the
-	 * audio file file. In short audiofile = audiofile(audiofile)
+	 * audio file file. In short: audiofile = audiofile(audiofile)
 	 */
 	if (is_audio (filename)) {
 		GP_DEBUG ("canon_int_filename2audioname: \"%s\" IS an audio file",
@@ -268,22 +330,18 @@ canon_int_filename2audioname (Camera *camera, const char *filename)
 	}
 
 	/* There are only audio files for images and movies */
-	if (!is_movie (filename) && !is_image (filename)) {
+	if (!(is_movie (filename) || is_image (filename))) {
 		GP_DEBUG ("canon_int_filename2audioname: "
 			  "\"%s\" is neither movie nor image -> no audio file", filename);
 		return NULL;
 	}
 
-	GP_DEBUG ("canon_int_filename2audioname: audio for file \"%s\" is external",
-		  filename);
+	result = filename_to_audio (filename, ".WAV");
 
-	/* We just replace file ending by .WAV and assume this is the
-	 * name of the audio file.
-	 */
-	return replace_filename_extension (filename, ".WAV");
+	GP_DEBUG ("canon_int_filename2audioname: audio for file \"%s\" is external: \"%s\"",
+		  filename, result);
 
-	/* never reached */
-	return NULL;
+	return result;
 }
 
 /**
@@ -1607,7 +1665,9 @@ debug_fileinfo (CameraFileInfo * info)
  * @flags: #canonDirlistFunctionBits specifying to list files, folders, or both
  * @context: context for error reporting
  *
- * Gets the directory tree of a given flash device.
+ * Gets the directory tree of a given flash device, unsorted and with
+ * a few missing features (such as correct sorting of files and
+ * correctly associating files with each other).
  *
  * Implicitly assumes that uint8_t[] is a char[] for strings.
  *
@@ -1865,8 +1925,8 @@ canon_int_list_directory (Camera *camera, const char *folder, CameraList *list,
 					 */
 					if (!camera->pl->list_all_files
 					    && !is_image (info.file.name)
-					    && !is_audio (info.file.name)
 					    && !is_movie (info.file.name)) {
+                                                /* FIXME: Find associated main file and add it there */
 						/* do nothing */
 						GP_DEBUG ("Ignored %s/%s", folder,
 							  info.file.name);
