@@ -3,7 +3,7 @@
  *
  * Written 1999 by Wolfgang G. Reissnegger and Werner Almesberger
  *
- * $Id: canon.h,v 1.77 2003/07/10 21:35:38 swestin Exp $
+ * $Id: canon.h,v 1.83 2003/10/10 10:54:32 marcusmeissner Exp $
  *
  */
 
@@ -62,6 +62,7 @@ typedef enum {
  * @CANON_PS_A50: PowerShot A50
  * @CANON_PS_A60: PowerShot A60
  * @CANON_PS_A70: PowerShot A70
+ * @CANON_PS_A80: PowerShot A80
  * @CANON_PS_PRO70: PowerShot Pro70
  * @CANON_PS_S10: PowerShot S10
  * @CANON_PS_S20: PowerShot S20
@@ -88,8 +89,15 @@ typedef enum {
  * @CANON_PS_G3: PowerShot G3
  * @CANON_PS_S230: PowerShot S230, Digital IXUS v3
  * @CANON_PS_A60: PowerShot A60
+ * @CANON_MV630I: MV630i camcorder
  * @CANON_EOS_10D: EOS 10D
  * @CANON_OPT_200: Optura 200 MC, MVX2i
+ * @CANON_PS_UNK1: Unknown camera seen in Mac OS X Image Capture
+ * @CANON_PS_UNK2: Unknown camera seen in Mac OS X Image Capture
+ * @CANON_PS_UNK3: Unknown camera seen in Mac OS X Image Capture
+ * @CANON_PS_UNK4: Unknown camera seen in Mac OS X Image Capture
+ * @CANON_PS_UNK5: Unknown camera seen in Mac OS X Image Capture
+ * @CANON_EOS_300D: EOS 300D / Digital Rebel / KISS Rebel
  *
  * Enumeration of all camera types currently supported.
  *
@@ -100,6 +108,7 @@ typedef enum {
 	CANON_PS_A50,
 	CANON_PS_A60,
 	CANON_PS_A70,
+	CANON_PS_A80,
 	CANON_PS_S10,
 	CANON_PS_S20,
 	CANON_PS_S30,
@@ -121,12 +130,23 @@ typedef enum {
 	CANON_PS_A100,
 	CANON_PS_A200,
 	CANON_PS_A300,
+	CANON_PS_S50,
 	CANON_PS_S45,
 	CANON_PS_G3,
-	CANON_PS_S50,
 	CANON_PS_S230,
+	CANON_MV630I,
 	CANON_EOS_10D,
-	CANON_OPT_200
+	CANON_OPT_200,
+	/* In Mac OS Image Capture, but not yet seen in the wild. */
+	CANON_PS_UNK1,
+	CANON_PS_UNK2,
+	CANON_PS_UNK3,
+	CANON_PS_UNK4,
+	CANON_PS_UNK5,
+	/* other cameras */
+	CANON_PS_S400,
+	CANON_PS_SD100,
+	CANON_EOS_300D
 } canonCamModel;
 
 /**
@@ -223,6 +243,7 @@ struct canonCamModelData
 	unsigned short usb_product;
 	canonCaptureSupport usb_capture_support;
 	unsigned int max_picture_size;
+	unsigned int max_movie_size;
 	unsigned int max_thumbnail_size;
 	char *serial_id_string; /* set to NULL if camera doesn't support serial connections */
 };
@@ -422,7 +443,8 @@ typedef enum {
  */
 #define IS_EOS(cam) ( ((cam)==CANON_EOS_D30) \
                       || ((cam)==CANON_EOS_D60) \
-                      || ((cam)==CANON_PS_S230 ) )
+                      || ((cam)==CANON_PS_S230) \
+                      || ((cam)==CANON_PS_S400) )
 
 /*
  * All functions returning a pointer have malloc'ed the data. The caller must
