@@ -11,7 +11,7 @@
  * This file contains all the "glue code" required to use the canon
  * driver with libgphoto2.
  *
- * $Id: library.c,v 1.75 2003/07/11 12:45:13 asl Exp $
+ * $Id: library.c,v 1.80 2003/09/03 22:36:26 hun Exp $
  *
  ****************************************************************************/
 
@@ -478,6 +478,10 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 	unsigned int datalen;
 	char canon_path[300];
 
+	/* for debugging */
+	char *filetype;
+	char buf[32];
+
 	/* put complete canon path into canon_path */
 	ret = snprintf (canon_path, sizeof (canon_path) - 3, "%s\\%s",
 			gphoto2canonpath (camera, folder, context), filename);
@@ -488,28 +492,31 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 		return GP_ERROR;
 	}
 
-	GP_DEBUG ("get_file_func: folder '%s' filename '%s' (i.e. '%s'), getting %s",
-		  folder, filename, canon_path,
-		  (type == GP_FILE_TYPE_PREVIEW) ? "thumbnail" : "file itself");
-
-	/* preparation, if it is _PREVIEW or _EXIF we get the thumbnail name */
-	if (type == GP_FILE_TYPE_PREVIEW || type == GP_FILE_TYPE_EXIF) {
-		thumbname = canon_int_filename2thumbname (camera, canon_path);
-		if (thumbname == NULL) {
-			/* no thumbnail available */
-			gp_context_error (context,
-					  _("No thumbnail could be found for %s"),
-					  canon_path);
-			ret = GP_ERROR;
-		} 
+	/* for debugging */
+	switch (type) {
+	case GP_FILE_TYPE_PREVIEW: filetype = "thumbnail"; break;
+	case GP_FILE_TYPE_EXIF: filetype = "exif data"; break;
+	case GP_FILE_TYPE_AUDIO: filetype = "audio annotation"; break;
+	case GP_FILE_TYPE_NORMAL: filetype = "file itself"; break;
+	default: snprintf(buf, sizeof(buf), "unknown type %d", type); filetype = buf; break;
 	}
+	GP_DEBUG ("get_file_func: folder '%s' filename '%s' (i.e. '%s'), getting %s",
+		  folder, filename, canon_path, filetype);
 
-	/* preparation, if it is _PREVIEW or _EXIF we get the thumbnail name */
+	/* preparation, if it is _AUDIO we convert the file name to
+	 * the corresponding audio file name. If the name of the audio
+	 * file is supplied, this step will be a no-op. */
 	if (type == GP_FILE_TYPE_AUDIO) {
 		audioname = canon_int_filename2audioname (camera, canon_path);
+		if (audioname == NULL) {
+			gp_context_error (context,
+					  _("No audio file could be found for %s"),
+					  canon_path);
+			return(GP_ERROR_FILE_NOT_FOUND);
+		}
 	}
 
-	/* fetch image/thumbnail/exif */	
+	/* fetch file/thumbnail/exif/audio/whatever */
 	switch (type) {
 		case GP_FILE_TYPE_NORMAL:
 			ret = canon_int_get_file (camera, canon_path, &data, &datalen,
@@ -535,26 +542,33 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 							       attr, context);
 			}
 			break;
+
 		case GP_FILE_TYPE_AUDIO:
-			if ((audioname != NULL) && (*audioname != '\0')) {
+			if (*audioname != '\0') {
 				/* extra audio file */
 				ret = canon_int_get_file (camera, audioname, &data, &datalen,
-							  context);				
+							  context);
 			} else {
-				gp_context_error (context,
-						  _("No audio file could be found for %s"),
-						  canon_path);
-				ret = GP_ERROR;
+				/* internal audio file; not handled yet */
+				ret = GP_ERROR_NOT_SUPPORTED;
 			}
 			break;
+
 		case GP_FILE_TYPE_PREVIEW:
+			thumbname = canon_int_filename2thumbname (camera, canon_path);
+			if (thumbname == NULL) {
+				/* no thumbnail available */
+				GP_DEBUG (_("%s is a file type for which no thumbnail is provided"));
+				return (GP_ERROR_NOT_SUPPORTED);
+			}
 #ifdef HAVE_EXIF
-			/* Check if we have libexif, it is an image and it is not
-			 * a PS A70 (which does not support EXIF), return not
+			/* Check if we have libexif, it is a jpeg file
+			 * and it is not a PowerShot Pro 70 (which
+			 * does not support EXIF), return not
 			 * supported here so that gPhoto2 query for
 			 * GP_FILE_TYPE_EXIF instead
 			 */
-			if (is_image (filename)) {
+			if (is_jpeg (filename)) {
 				if (camera->pl->md->model != CANON_PS_PRO70) {
 					GP_DEBUG ("get_file_func: preview requested where "
 						  "EXIF should be possible");
@@ -572,12 +586,20 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 							  context);
 			}
 			break;
+
 		case GP_FILE_TYPE_EXIF:
 #ifdef HAVE_EXIF
-			/* the PS A70 does not support EXIF */
+			/* the PowerShot Pro 70 does not support EXIF */
 			if (camera->pl->md->model == CANON_PS_PRO70)
 				return (GP_ERROR_NOT_SUPPORTED);
-				
+
+			thumbname = canon_int_filename2thumbname (camera, canon_path);
+			if (thumbname == NULL) {
+				/* no thumbnail available */
+				GP_DEBUG (_("%s is a file type for which no thumbnail is provided"));
+				return (GP_ERROR_NOT_SUPPORTED);
+			}
+
 			if (*thumbname == '\0') {
 				/* file internal thumbnail with EXIF data */
 				ret = canon_int_get_thumbnail (camera, canon_path, &data,
@@ -591,7 +613,8 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 			GP_DEBUG ("get_file_func: EXIF file type requested but no libexif");
 			return (GP_ERROR_NOT_SUPPORTED);
 #endif /* HAVE_EXIF */
-			break;		
+			break;
+
 		default:
 			GP_DEBUG ("get_file_func: unsupported file type %i", type);
 			return (GP_ERROR_NOT_SUPPORTED);
@@ -617,7 +640,7 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 	}
 
 	/* do different things with the data fetched above */
-	
+	/* FIXME: For which file type(s) should we gp_file_set_name(file,filename) ? */
 	switch (type) {
 		case GP_FILE_TYPE_PREVIEW:
 			/* Either this camera model does not support EXIF,
@@ -627,7 +650,7 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 			 * in data.
 			 */
 			ret = canon_int_extract_jpeg_thumb (data, datalen, &thumbdata, &datalen, context);
-			
+
 			if (thumbdata != NULL) {
 				/* free old data */
 				free (data);
@@ -648,8 +671,13 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 			gp_file_set_mime_type (file, GP_MIME_JPEG);	/* always */
 			gp_file_set_name (file, filename);
 			break;
-	        case GP_FILE_TYPE_AUDIO:
+
+		case GP_FILE_TYPE_AUDIO:
 			gp_file_set_mime_type (file, GP_MIME_WAV);
+			gp_file_set_data_and_size (file, data, datalen);
+			gp_file_set_name (file, filename);
+			break;
+
 		case GP_FILE_TYPE_NORMAL:
 			gp_file_set_mime_type (file, filename2mimetype (filename));
 			gp_file_set_data_and_size (file, data, datalen);
@@ -660,7 +688,7 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 			gp_file_set_mime_type (file, GP_MIME_JPEG);
 			gp_file_set_data_and_size (file, data, datalen);
 			break;
-#endif /* HAVE_EXIF */			
+#endif /* HAVE_EXIF */
 		default:
 			/* this case should've been caught above anyway */
 			if (data)
