@@ -4,7 +4,7 @@
  *
  * USB communication layer.
  *
- * $Id: usb.c,v 1.76 2003/07/10 21:35:38 swestin Exp $
+ * $Id: usb.c,v 1.80 2003/09/20 17:42:44 hun Exp $
  ****************************************************************************/
 
 #include "config.h"
@@ -331,8 +331,10 @@ canon_usb_lock_keys (Camera *camera, GPContext *context)
 			break;
 		case CANON_EOS_D30:
 		case CANON_EOS_D60:
-                case CANON_EOS_10D:
+		case CANON_EOS_10D:
+		case CANON_EOS_300D:
 		case CANON_PS_S230:
+		case CANON_PS_S400:
 			GP_DEBUG ("Locking camera keys and turning off LCD using 'EOS' locking code...");
 
 			memset (payload, 0, sizeof (payload));
@@ -453,8 +455,10 @@ canon_usb_unlock_keys (Camera *camera, GPContext *context)
 	switch (camera->pl->md->model) {
 		case CANON_EOS_D30:
 		case CANON_EOS_D60:
-	        case CANON_EOS_10D:
+		case CANON_EOS_10D:
+		case CANON_EOS_300D:
 		case CANON_PS_S230:
+		case CANON_PS_S400:
 			c_res = canon_usb_dialogue (camera, CANON_USB_FUNCTION_EOS_UNLOCK_KEYS,
 						    &bytes_read, NULL, 0);
 			if (!c_res)
@@ -472,11 +476,11 @@ canon_usb_unlock_keys (Camera *camera, GPContext *context)
 			break;
 		default:
 			/* Your camera model does not need unlocking, cannot do unlocking or
-			 * we don't know how to unlock it's keys. If unlocking works when
-			 * using the Windows software with your camera, please contact
-			 * <gphoto-devel@gphoto.net>
+			 * we don't know how to unlock it's keys. 
 			 */
-			GP_DEBUG ("canon_usb_unlock_keys: Not unlocking the kind of camera you have.");
+			GP_DEBUG ("canon_usb_unlock_keys: Not unlocking the kind of camera you have.\n"
+				  "If unlocking works when using the Windows software with your camera,\n"
+				  "please contact %s.", MAIL_GPHOTO_DEVEL);
 			break;
 	}
 
@@ -548,10 +552,10 @@ static int canon_usb_poll_interrupt_pipe ( Camera *camera, unsigned char *buf, i
  *  gphoto2 error code from read that results in an I/O error.
  *
  */
-static int canon_usb_poll_interrupt_multiple ( Camera *camera[], int n_cameras,
-					       int camera_flags[],
-					       unsigned char *buf, int n_tries,
-					       int *which )
+int canon_usb_poll_interrupt_multiple ( Camera *camera[], int n_cameras,
+					int camera_flags[],
+					unsigned char *buf, int n_tries,
+					int *which )
 {
 	int i = 0, status = 0;
 
