@@ -38,7 +38,7 @@
 #    define N_(String) gettext_noop (String)
 #  else
 #    define N_(String) (String)
-#  endif 
+#  endif
 #else
 #  define textdomain(String) (String)
 #  define gettext(String) (String)
@@ -226,7 +226,7 @@ camera_abilities (CameraAbilitiesList* list)
                                GP_OPERATION_CAPTURE_IMAGE |
                                GP_OPERATION_CAPTURE_PREVIEW;
                 a.file_operations = GP_FILE_OPERATION_DELETE |
-                                    GP_FILE_OPERATION_PREVIEW | 
+                                    GP_FILE_OPERATION_PREVIEW |
 				    GP_FILE_OPERATION_EXIF;
                 a.folder_operations = GP_FOLDER_OPERATION_DELETE_ALL;
                 gp_abilities_list_append (list, a);
@@ -314,7 +314,7 @@ static int
 test_speed (Camera *camera, GPContext *context)
 {
 	int i;
-	unsigned int speeds[] = {115200, 9600, 57600, 38400, 19200, 
+	unsigned int speeds[] = {115200, 9600, 57600, 38400, 19200,
 				 4800, 2400, 1200, 600, 300};
 	unsigned int id;
 	GPPortSettings settings;
@@ -1128,7 +1128,7 @@ localization_file_read (Camera *camera, const char *file_name,
                 default:
                         /****************************************/
                         /* j == 0: We have to read the second   */
-                        /*         half of the byte to send.    */
+                        /* half of the byte to send.            */
                         /* j == 1: We'll compose our byte.      */
                         /****************************************/
                         if ((f != '0') && (f != '1') && (f != '2') &&
@@ -1248,9 +1248,9 @@ camera_init (Camera* camera, GPContext *context)
                 /* Initiate the connection */
 		C(speed = test_speed (camera, context));
 #if 0
-//Ideally, we need to reset the speed to the speed that we encountered
-//after each operation (multiple programs accessing the camera). However,
-//that takes quite a bit of time for HP cameras...
+/* Ideally, we need to reset the speed to the speed that we encountered
+   after each operation (multiple programs accessing the camera). However,
+   that takes quite a bit of time for HP cameras... */
 		camera->pl->speed = speed;
 #endif
 
