@@ -49,6 +49,9 @@
 
 #define GP_MODULE "PTP2"
 
+#define USB_TIMEOUT 8000
+#define USB_TIMEOUT_CAPTURE 20000
+
 #define CPR(context,result) {short r=(result); if (r!=PTP_RC_OK) {report_result ((context), r); return (translate_ptp_result (r));}}
 
 #define CPR_free(context,result, freeptr) {\
@@ -70,11 +73,21 @@
 				}\
 }
 */
+/* below macro makes a copy of fn without leading character ('/'),
+ * removes the '/' at the end if present, and calls folder_to_handle()
+ * funtion proviging as the first argument the string after the second '/'.
+ * for example if fn is '/store_00010001/DCIM/somefolder/', the macro will
+ * call folder_to_handle() with 'DCIM/somefolder' as the very first argument.
+ * it's used to omit storage pseudofolder and remove trailing '/'
+ */
+
 #define find_folder_handle(fn,s,p,d)	{			\
 		{						\
-		char *backfolder=malloc(strlen(fn));		\
+		int len=strlen(fn);				\
+		char *backfolder=malloc(len);			\
 		char *tmpfolder;				\
-		memcpy(backfolder,fn+1, strlen(fn));		\
+		memcpy(backfolder,fn+1, len);			\
+		if (backfolder[len-2]=='/') backfolder[len-2]='\0';\
 		if ((tmpfolder=strchr(backfolder+1,'/'))==NULL) tmpfolder="/";\
 		p=folder_to_handle(tmpfolder+1,s,0,(Camera *)d);\
 		free(backfolder);				\
@@ -87,14 +100,14 @@
 		{						\
 			if (strlen(fn)<strlen(STORAGE_FOLDER_PREFIX)+8+1) \
 				return (GP_ERROR);		\
-			s = strtol(fn + strlen(STORAGE_FOLDER_PREFIX)+1, NULL, 16);								\
+			s = strtoul(fn + strlen(STORAGE_FOLDER_PREFIX)+1, NULL, 16);								\
 		} else return (GP_ERROR);			\
 		}						\
 }
 
 #define STORAGE_FOLDER_PREFIX		"store_"
 
-// PTP error descriptions
+/* PTP error descriptions */
 static struct {
 	short n;
 	const char *txt;
@@ -200,7 +213,7 @@ static struct {
 	 */
 	{"Kodak:DC4800", 0x040a, 0x0160},
 	/* Below other camers known to be detected by interface class */
-	
+
 	{"Kodak:DX3900", 0x040a, 0x0170},
 	{"Kodak:MC3",    0x040a, 0x0400},
 	{"Kodak:DX3500", 0x040a, 0x0500},
@@ -223,12 +236,14 @@ static struct {
 	{"Kodak:DX6440", 0x040a, 0x0572},
 	{"Kodak:CX6230", 0x040a, 0x0573},
 	{"Kodak:CX6200", 0x040a, 0x0574},
+	{"Kodak:DX6490", 0x040a, 0x0575},
 	{"Kodak:DX4530", 0x040a, 0x0576},
 
-
 	/* HP PTP cameras */
 	{"HP:PhotoSmart 812 (PTP mode)", 0x03f0, 0x4202},
 	{"HP:PhotoSmart 850 (PTP mode)", 0x03f0, 0x4302},
+	/* HP PhotoSmart 935: T. Kaproncai, 25 Jul 2003*/
+	{"HP:PhotoSmart 935 (PTP mode)", 0x03f0, 0x4402},
 	{"HP:PhotoSmart 318 (PTP mode)", 0x03f0, 0x6302},
 	{"HP:PhotoSmart 612 (PTP mode)", 0x03f0, 0x6302},
 	{"HP:PhotoSmart 715 (PTP mode)", 0x03f0, 0x6402},
@@ -237,6 +252,8 @@ static struct {
 	{"HP:PhotoSmart 720 (PTP mode)", 0x03f0, 0x6702},
 	{"HP:PhotoSmart 620 (PTP mode)", 0x03f0, 0x6802},
 	{"HP:PhotoSmart 735 (PTP mode)", 0x03f0, 0x6a02},
+	/* report from Federico Prat Villar <fprat@lsi.uji.es> */
+	{"HP:PhotoSmart 43x (PTP mode)", 0x03f0, 0x7202},
 
 	/* I got information that all SONY PTP cameras use the same
 	   product/vendor IDs */
@@ -244,22 +261,32 @@ static struct {
 	{"Sony:DSC-F707V (PTP mode)", 0x054c, 0x004e},
 	{"Sony:DSC-P30 (PTP mode)",   0x054c, 0x004e},
 	/* P32 reported on May 1st by Justin Alexander <justin (at) harshangel.com> */
+	{"Sony:DSC-P31 (PTP mode)",   0x054c, 0x004e}, 
 	{"Sony:DSC-P32 (PTP mode)",   0x054c, 0x004e}, 
 	{"Sony:DSC-P50 (PTP mode)",   0x054c, 0x004e},
 	{"Sony:DSC-S75 (PTP mode)",   0x054c, 0x004e},
 	{"Sony:DSC-S85 (PTP mode)",   0x054c, 0x004e},
+	{"Sony:DSC-V1 (PTP mode)",   0x054c, 0x004e},
 	{"Sony:MVC-CD300 (PTP mode)", 0x054c, 0x004e},
 
 	/* Nikon Coolpix 2500: M. Meissner, 05 Oct 2003 */
 	{"Nikon:Coolpix 2500 (PTP mode)", 0x04b0, 0x0109},
 	/* Nikon Coolpix 5700: A. Tanenbaum, 29 Oct 2002 */
 	{"Nikon:Coolpix 5700 (PTP mode)", 0x04b0, 0x010d},
+	/* Nikon CoolPix 4500: T. Kaproncai, 22 Aug 2003 */
+	{"Nikon CoolPix 4500 (PTP mode)", 0x04b0, 0x010b},
 	/* Nikon Coolpix 4300: Marco Rodriguez, 10 dic 2002 */
 	{"Nikon:Coolpix 4300 (PTP mode)", 0x04b0, 0x010f},
 	/* Nikon Coolpix 3500: M. Meissner, 07 May 2003 */
 	{"Nikon:Coolpix 3500 (PTP mode)", 0x04b0, 0x0111},
 	/* Nikon Coolpix 885: S. Anderson, 19 nov 2002 */
 	{"Nikon:Coolpix 885 (PTP mode)",  0x04b0, 0x0112},
+	/* Nikon Coolpix 5000, Firmware v1.7 or later */
+	{"Nikon:Coolpix 5000 (PTP mode)", 0x04b0, 0x0113},
+	/* Nikon Coolpix 3100 */
+	{"Nikon:Coolpix 3100 (PTP mode)", 0x04b0, 0x0115},
+	/* Nikon Coolpix 2100 */
+	{"Nikon:Coolpix 2100 (PTP mode)", 0x04b0, 0x0117},
 	/* Nikon Coolpix 5400: T. Kaproncai, 25 Jul 2003 */
 	{"Nikon:Coolpix 5400 (PTP mode)", 0x04b0, 0x0119},
 	/* Nikon Coolpix SQ: M. Holzbauer, 07 Jul 2003 */
@@ -271,21 +298,30 @@ static struct {
 
 
 	/* (at least some) newer Canon cameras can be switched between
-	 * PTP and "normal" (i.e. Canon) mode 
+	 * PTP and "normal" (i.e. Canon) mode
 	 * Canon PS G3: A. Marinichev, 20 nov 2002
 	 */
-	{"Canon:PowerShot S45 (PTP mode)",   0x04a9, 0x306d},
+	{"Canon:PowerShot S45 (PTP mode)",      0x04a9, 0x306d},
 		/* 0x306c is S45 in normal (canon) mode */
-	{"Canon:PowerShot G3 (PTP mode)",    0x04a9, 0x306f},
+	{"Canon:PowerShot G3 (PTP mode)",       0x04a9, 0x306f},
 		/* 0x306e is G3 in normal (canon) mode */
-	{"Canon:PowerShot S230 (PTP mode)",  0x04a9, 0x3071},
+	{"Canon:PowerShot S230 (PTP mode)",     0x04a9, 0x3071},
 		/* 0x3070 is S230 in normal (canon) mode */
-	{"Canon:Digital IXUS v3 (PTP mode)", 0x04a9, 0x3071},
+	{"Canon:Digital IXUS v3 (PTP mode)",    0x04a9, 0x3071},
 		/* it's the same as S230 */
-	{"Canon:PowerShot A70 (PTP)",        0x04a9, 0x3073},
-		/* A60 and A70 are PTP also */
-	{"Canon:PowerShot A60 (PTP)",        0x04a9, 0x3074},
-	{"Canon:PowerShot G5 (PTP mode)",    0x04a9, 0x3085},
+
+	{"Canon:Digital IXUS 2 (PTP mode)",     0x04a9, 0x3072},
+
+	{"Canon:PowerShot A70 (PTP)",           0x04a9, 0x3073},
+	{"Canon:PowerShot A60 (PTP)",           0x04a9, 0x3074},
+	{"Canon:PowerShot A80 (PTP)",           0x04a9, 0x309A},
+		/* IXUS 400 has the same PID in both modes, Till Kamppeter */
+	{"Canon:Digital IXUS 400 (PTP mode)",   0x04a9, 0x3075},
+	{"Canon:PowerShot G5 (PTP mode)",       0x04a9, 0x3085},
+		/* 0x3084 is the EOS 300D/Digital Rebel in normal (canon) mode */
+	{"Canon:EOS 300D (PTP mode)",           0x04a9, 0x3099},
+	{"Canon:EOS Digital Rebel (PTP mode)",  0x04a9, 0x3099},
+	{"Canon:EOS Kiss Digital (PTP mode)",   0x04a9, 0x3099},
 
 	/* more coming soon :) */
 	{NULL, 0, 0}
@@ -486,7 +522,7 @@ camera_abilities (CameraAbilitiesList *list)
 	memset(&a,0, sizeof(a));
 	for (i = 0; models[i].model; i++) {
 		strcpy (a.model, models[i].model);
-		a.status = GP_DRIVER_STATUS_TESTING;
+		a.status = GP_DRIVER_STATUS_PRODUCTION;
 		a.port   = GP_PORT_USB;
 		a.speed[0] = 0;
 		a.usb_vendor = models[i].usb_vendor;
@@ -508,11 +544,12 @@ camera_abilities (CameraAbilitiesList *list)
 	a.usb_class = 6;
 	a.usb_subclass = -1;
 	a.usb_protocol = -1;
-	a.operations        = GP_OPERATION_NONE;
+	a.operations        = GP_CAPTURE_IMAGE | GP_OPERATION_CONFIG;
 	a.file_operations   = GP_FILE_OPERATION_PREVIEW|
 				GP_FILE_OPERATION_DELETE;
 	a.folder_operations = GP_FOLDER_OPERATION_PUT_FILE
-		| GP_FOLDER_OPERATION_MAKE_DIR;
+		| GP_FOLDER_OPERATION_MAKE_DIR |
+		GP_FOLDER_OPERATION_REMOVE_DIR;
 	CR (gp_abilities_list_append (list, a));
 
 	return (GP_OK);
@@ -561,6 +598,33 @@ camera_about (Camera *camera, CameraText *text, GPContext *context)
 	return (GP_OK);
 }
 
+/* add new object to internal driver structures. issued when creating
+folder, uploading objects, or captured images. */
+static int
+add_object (Camera *camera, uint32_t handle, GPContext *context)
+{
+	int n;
+
+	/* increase number of objects */
+	n=++camera->pl->params.handles.n;
+	/* realloc more space for camera->pl->params.objectinfo */
+	camera->pl->params.objectinfo = (PTPObjectInfo*)
+		realloc(camera->pl->params.objectinfo,
+			sizeof(PTPObjectInfo)*n);
+	/* realloc more space for amera->pl->params.handles.Handler */
+	camera->pl->params.handles.Handler= (uint32_t *)
+		realloc(camera->pl->params.handles.Handler,
+			sizeof(uint32_t)*n);
+	/* clear objectinfo entry for new object and assign new handler */
+	memset(&camera->pl->params.objectinfo[n-1],0,sizeof(PTPObjectInfo));
+	camera->pl->params.handles.Handler[n-1]=handle;
+	/* get new obectinfo */
+	CPR (context, ptp_getobjectinfo(&camera->pl->params,
+		handle,
+		&camera->pl->params.objectinfo[n-1]));
+	return (GP_OK);
+}
+
 static int
 camera_capture (Camera *camera, CameraCaptureType type, CameraFilePath *path,
 		GPContext *context)
@@ -572,9 +636,19 @@ camera_capture (Camera *camera, CameraCaptureType type, CameraFilePath *path,
 	}
 
 	if (!ptp_operation_issupported(&camera->pl->params,
-		PTP_OC_InitiateCapture)) return GP_ERROR_NOT_SUPPORTED;
+		PTP_OC_InitiateCapture))
+		return GP_ERROR_NOT_SUPPORTED;
 
+	/* A capture may take longer than the standard 8 seconds.
+	 * The G5 for instance does, or in dark rooms ...
+	 * Even 16 seconds might not be enough. (Marcus)
+	 */
+	/* ptp_initiatecapture() returns immediately, only the event
+	 * indicating that the capure has been completed may occur after
+	 * few seconds. moving down the code. (kil3r)
+	 */
 	CPR(context,ptp_initiatecapture(&camera->pl->params, 0x00000000, 0x00000000));
+	CR (gp_port_set_timeout (camera->port, USB_TIMEOUT_CAPTURE));
 	while (ptp_usb_event_wait (&camera->pl->params, &event)!=PTP_RC_OK);
 	if (event.Code==PTP_EC_ObjectAdded) {
 		while (ptp_usb_event_wait (&camera->pl->params, &event)!=PTP_RC_OK);
@@ -582,6 +656,7 @@ camera_capture (Camera *camera, CameraCaptureType type, CameraFilePath *path,
 			return GP_OK;
 		}
 	} 
+	CR (gp_port_set_timeout (camera->port, USB_TIMEOUT));
 
 	/* we're not going to set path, ptp does not use paths anyway ;) */
 	return GP_ERROR;
@@ -590,18 +665,23 @@ camera_capture (Camera *camera, CameraCaptureType type, CameraFilePath *path,
 static int
 camera_summary (Camera* camera, CameraText* summary, GPContext *context)
 {
-	snprintf (summary->text, sizeof (summary->text),
+	int n;
+	n = snprintf (summary->text, sizeof (summary->text),
 		_("Model: %s\n"
 		"  device version: %s\n"
 		"  serial number:  %s\n"
 		"Vendor extension ID: 0x%08x\n"
-		"Vendor extension description: %s\n"),
+		"Vendor extension description: %s\n"
+	),
 		camera->pl->params.deviceinfo.Model,
 		camera->pl->params.deviceinfo.DeviceVersion,
 		camera->pl->params.deviceinfo.SerialNumber,
 		camera->pl->params.deviceinfo.VendorExtensionID,
 		camera->pl->params.deviceinfo.VendorExtensionDesc);
+	if (n>=sizeof(summary->text))
+		return GP_OK;
 
+	
 	return (GP_OK);
 }
 
@@ -628,7 +708,11 @@ camera_get_config (Camera *camera, CameraWidget **window, GPContext *context)
 		window);
 	gp_widget_new (GP_WIDGET_SECTION, _("Power (readonly)"), &section);
 	gp_widget_append (*window, section);
-	if (dpd.FormFlag==PTP_DPFF_Enumeration){
+	switch (dpd.FormFlag) {
+	case PTP_DPFF_Enumeration: {
+		uint16_t i;
+		char tmp[64];
+
 		GP_DEBUG ("Number of values %i",
 			dpd.FORM.Enum.NumberOfValues);
 		gp_widget_new (GP_WIDGET_TEXT, _("Number of values"),&widget);
@@ -637,14 +721,10 @@ camera_get_config (Camera *camera, CameraWidget **window, GPContext *context)
 		gp_widget_append (section,widget);
 		gp_widget_new (GP_WIDGET_TEXT, _("Supported values"),&widget);
 		value[0]='\0';
-		{
-		uint16_t i;
-		char tmp[64];
 		for (i=0;i<dpd.FORM.Enum.NumberOfValues;i++){
 			snprintf (tmp,6,"|%.3i|",
 			*(uint8_t *)dpd.FORM.Enum.SupportedValue[i]);
 			strncat(value,tmp,6);
-			}
 		}
 		gp_widget_set_value (widget,value);
 		gp_widget_append (section,widget);
@@ -652,6 +732,23 @@ camera_get_config (Camera *camera, CameraWidget **window, GPContext *context)
 		snprintf (value,255,"%i",*(uint8_t *)dpd.CurrentValue);
 		gp_widget_set_value (widget,value);
 		gp_widget_append (section,widget);
+		break;
+	}
+	case PTP_DPFF_Range: {
+		float value_float;
+                fprintf (stderr,", within range: %d - %d, stepping %d\n", *(uint8_t*)dpd.FORM.Range.MinimumValue, *(uint8_t*)dpd.FORM.Range.MaximumValue, *(uint8_t*)dpd.FORM.Range.StepSize);
+		gp_widget_new (GP_WIDGET_RANGE, _("Power (readonly)"), &widget);
+		gp_widget_append (section,widget);
+		gp_widget_set_range (widget, *(uint8_t*)dpd.FORM.Range.MinimumValue, *(uint8_t*)dpd.FORM.Range.MaximumValue, *(uint8_t*)dpd.FORM.Range.StepSize);
+        	/* this is a write only capability */
+        	value_float = *(uint8_t *)dpd.CurrentValue;
+        	gp_widget_set_value (widget, &value_float);
+        	gp_widget_changed(widget);
+                break;
+	}
+        case PTP_DPFF_None:
+		break;
+	default: break;
 	}
 	ptp_free_devicepropdesc(&dpd);
 	return GP_OK;
@@ -799,7 +896,7 @@ folder_list_func (CameraFilesystem *fs, const char *folder, CameraList *list,
 			char fname[PTP_MAXSTRLEN];
 			PTPStorageInfo storageinfo;
 			if ((storageids.Storage[i]&0x0000ffff)==0) continue;
-			if (ptp_operation_issupported(params,PTP_OC_GetStorageIDs)) {
+			if (ptp_operation_issupported(params,PTP_OC_GetStorageInfo)) {
 				CPR (context, ptp_getstorageinfo(params,
 					storageids.Storage[i], &storageinfo));
 			}
@@ -859,10 +956,12 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 	GP_DEBUG ("Getting file.");
 	switch (type) {
 
+	case	GP_FILE_TYPE_EXIF:
+		/* Ups... no easy way to obtain plain EXIF information */
+		return (GP_ERROR_NOT_SUPPORTED);
+
 	case	GP_FILE_TYPE_PREVIEW:
-		/* Don't allow to get thumb of nonimage objects! */
-		if ((oi->ObjectFormat & 0x0800) == 0) return (GP_ERROR_NOT_SUPPORTED);
-		/* if no thumb, for some reason */
+		/* If thumb size is 0 then there is no thumbnail at all... */
 		if((size=oi->ThumbCompressedSize)==0) return (GP_ERROR_NOT_SUPPORTED);
 		CPR (context, ptp_getthumb(&camera->pl->params,
 			camera->pl->params.handles.Handler[object_id],
@@ -929,7 +1028,12 @@ put_file_func (CameraFilesystem *fs, const char *folder, CameraFile *file,
 	oi.ObjectFormat=get_mimetype(camera, file);
 	oi.ObjectCompressedSize=size;
 	gp_file_get_mtime(file, &oi.ModificationDate);
-	if (ptp_operation_issupported(params, PTP_OC_EK_SendFileObject)) {
+	/* if the device is usign PTP_VENDOR_EASTMAN_KODAK extension try
+	 * PTP_OC_EK_SendFileObject
+	 */
+	if ((params->deviceinfo.VendorExtensionID==PTP_VENDOR_EASTMAN_KODAK) &&
+		(ptp_operation_issupported(params, PTP_OC_EK_SendFileObject)))
+	{
 		CPR (context, ptp_ek_sendfileobjectinfo (params, &storage,
 			&parent, &handle, &oi));
 		CPR (context, ptp_ek_sendfileobject (params, object, size));
@@ -941,7 +1045,8 @@ put_file_func (CameraFilesystem *fs, const char *folder, CameraFile *file,
 		GP_DEBUG ("The device does not support uploading files!");
 		return GP_ERROR_NOT_SUPPORTED;
 	}
-
+	/* update internal structures */
+	add_object(camera, handle, context);
 	return (GP_OK);
 }
 
@@ -955,6 +1060,9 @@ delete_file_func (CameraFilesystem *fs, const char *folder,
 
 	((PTPData *) camera->pl->params.data)->context = context;
 
+	if (!ptp_operation_issupported(&camera->pl->params, PTP_OC_DeleteObject))
+		return GP_ERROR_NOT_SUPPORTED;
+
 	/* compute storage ID value from folder patch */
 	folder_to_storage(folder,storage);
 
@@ -980,6 +1088,9 @@ remove_dir_func (CameraFilesystem *fs, const char *folder,
 
 	((PTPData *) camera->pl->params.data)->context = context;
 
+	if (!ptp_operation_issupported(&camera->pl->params, PTP_OC_DeleteObject))
+		return GP_ERROR_NOT_SUPPORTED;
+
 	/* compute storage ID value from folder patch */
 	folder_to_storage(folder,storage);
 
@@ -1016,8 +1127,12 @@ get_info_func (CameraFilesystem *fs, const char *folder, const char *filename,
 		return (GP_ERROR_BAD_PARAMETERS);
 
 	oi=&camera->pl->params.objectinfo[object_id];
-	info->file.fields = GP_FILE_INFO_SIZE|GP_FILE_INFO_TYPE|GP_FILE_INFO_MTIME;
 
+	info->file.fields = GP_FILE_INFO_SIZE|GP_FILE_INFO_TYPE|GP_FILE_INFO_MTIME;
+	if (oi->Filename) {
+		strcpy(info->file.name, oi->Filename);
+		info->file.fields |= GP_FILE_INFO_NAME;
+	}
 	info->file.size   = oi->ObjectCompressedSize;
 	strcpy_mime (info->file.type, oi->ObjectFormat);
 	info->file.mtime = oi->ModificationDate;
@@ -1051,6 +1166,7 @@ make_dir_func (CameraFilesystem *fs, const char *folder, const char *foldername,
 	uint32_t parent;
 	uint32_t storage;
 	uint32_t handle;
+	PTPParams* params=&camera->pl->params;
 
 	((PTPData *) camera->pl->params.data)->context = context;
 	memset(&oi, 0, sizeof (PTPObjectInfo));
@@ -1072,13 +1188,22 @@ make_dir_func (CameraFilesystem *fs, const char *folder, const char *foldername,
 	oi.ProtectionStatus=PTP_PS_NoProtection;
 	oi.AssociationType=PTP_AT_GenericFolder;
 
-	CPR (context, ptp_ek_sendfileobjectinfo (&camera->pl->params,
-		&storage, &parent, &handle, &oi));
-	/* to create folder on kodak camera you don't have to sendfileobject */
-#if 0
-	CPR (context, ptp_ek_sendfileobject (&camera->pl->params,
-		&oi, 18));
-#endif
+	if ((params->deviceinfo.VendorExtensionID==
+			PTP_VENDOR_EASTMAN_KODAK) &&
+		(ptp_operation_issupported(params,
+			PTP_OC_EK_SendFileObjectInfo)))
+	{
+		CPR (context, ptp_ek_sendfileobjectinfo (params, &storage,
+			&parent, &handle, &oi));
+	} else if (ptp_operation_issupported(params, PTP_OC_SendObjectInfo)) {
+		CPR (context, ptp_sendobjectinfo (params, &storage,
+			&parent, &handle, &oi));
+	} else {
+		GP_DEBUG ("The device does not support make folder!");
+		return GP_ERROR_NOT_SUPPORTED;
+	}
+	/* update internal structures */
+	add_object(camera, handle, context);
 	return (GP_OK);
 }
 
@@ -1090,7 +1215,7 @@ init_ptp_fs (Camera *camera, GPContext *context)
 	((PTPData *) camera->pl->params.data)->context = context;
 
 	/* Get file handles array for filesystem */
-	id = gp_context_progress_start (context, 0, _("Initializing Camera"));
+	id = gp_context_progress_start (context, 100, _("Initializing Camera"));
 	/* be paranoid!!! */
 	memset (&camera->pl->params.handles, 0, sizeof(PTPObjectHandles));
 	/* get objecthandles of all objects from all stores */
@@ -1115,13 +1240,14 @@ init_ptp_fs (Camera *camera, GPContext *context)
 
 		oi=&camera->pl->params.objectinfo[i];
 		GP_DEBUG ("ObjectInfo for '%s':", oi->Filename);
-		GP_DEBUG ("  Object ID: 0x%.4x",
+		GP_DEBUG ("  Object ID: 0x%08x",
 			camera->pl->params.handles.Handler[i]);
-		GP_DEBUG ("  StorageID: 0x%.4x", oi->StorageID);
-		GP_DEBUG ("  ObjectFormat: 0x%.4x", oi->ObjectFormat);
+		GP_DEBUG ("  StorageID: 0x%08x", oi->StorageID);
+		GP_DEBUG ("  ObjectFormat: 0x%04x", oi->ObjectFormat);
+		GP_DEBUG ("  ProtectionStatus: 0x%04x", oi->ProtectionStatus);
 		GP_DEBUG ("  ObjectCompressedSize: %d",
 			oi->ObjectCompressedSize);
-		GP_DEBUG ("  ThumbFormat: 0x%.4x", oi->ThumbFormat);
+		GP_DEBUG ("  ThumbFormat: 0x%04x", oi->ThumbFormat);
 		GP_DEBUG ("  ThumbCompressedSize: %d",
 			oi->ThumbCompressedSize);
 		GP_DEBUG ("  ThumbPixWidth: %d", oi->ThumbPixWidth);
@@ -1129,18 +1255,18 @@ init_ptp_fs (Camera *camera, GPContext *context)
 		GP_DEBUG ("  ImagePixWidth: %d", oi->ImagePixWidth);
 		GP_DEBUG ("  ImagePixHeight: %d", oi->ImagePixHeight);
 		GP_DEBUG ("  ImageBitDepth: %d", oi->ImageBitDepth);
-		GP_DEBUG ("  ParentObject: 0x%.4x", oi->ParentObject);
-		GP_DEBUG ("  AssociationType: 0x%.4x", oi->AssociationType);
-		GP_DEBUG ("  AssociationDesc: 0x%.4x", oi->AssociationDesc);
-		GP_DEBUG ("  SequenceNumber: 0x%.4x", oi->SequenceNumber);
+		GP_DEBUG ("  ParentObject: 0x%08x", oi->ParentObject);
+		GP_DEBUG ("  AssociationType: 0x%04x", oi->AssociationType);
+		GP_DEBUG ("  AssociationDesc: 0x%08x", oi->AssociationDesc);
+		GP_DEBUG ("  SequenceNumber: 0x%08x", oi->SequenceNumber);
 		}
 #endif
 		gp_context_progress_update (context, id,
-		(90*i)/camera->pl->params.handles.n);
+		10+(90*i)/camera->pl->params.handles.n);
 	}
 	gp_context_progress_stop (context, id);
 
-/*
+#if 0
 	add_dir (camera, 0x00000000, 0xff000000, "DIR1");
 	add_dir (camera, 0x00000000, 0xff000001, "DIR20");
 	add_dir (camera, 0xff000000, 0xff000002, "subDIR1");
@@ -1148,8 +1274,8 @@ init_ptp_fs (Camera *camera, GPContext *context)
 	move_object_by_number (camera, 0xff000002, 2);
 	move_object_by_number (camera, 0xff000001, 3);
 	move_object_by_number (camera, 0xff000002, 4);
-	// Used for testing with my camera, which does not support subdirs
-*/
+	/* Used for testing with my camera, which does not support subdirs */
+#endif
 	return (GP_OK);
 }
 
@@ -1195,7 +1321,7 @@ camera_init (Camera *camera, GPContext *context)
 	/* On large fiels (over 50M) deletion takes over 3 seconds,
 	 * waiting for event after capture may take some time also
 	 */
-	CR (gp_port_set_timeout (camera->port, 8000));
+	CR (gp_port_set_timeout (camera->port, USB_TIMEOUT));
 	/* do we configure port ???*/
 #if 0	
 	/* Configure the port */
