@@ -147,8 +147,14 @@ static struct {
 	{"Olympus", "C-2100UZ", SIERRA_MODEL_CAM_DESC, 0x07b4, 0x100, 0,
 					&oly3040_cam_desc},
 	{"Olympus", "C-2500L",     SIERRA_MODEL_OLYMPUS,   0, 0, 0 },
+	/*
+	 * Note: The 3000z can't be auto selected, as it has the same USB
+	 * id as the 2040 (and others, but the others are still using the
+	 * the 3040 desc), so you have to set the camera "model" via the
+	 * front end (gtkam or gphoto2 command line) in order to use it.
+	 */
 	{"Olympus", "C-3000Z", 	SIERRA_MODEL_CAM_DESC,	0x07b4, 0x100, 0,
-							&oly3040_cam_desc},
+							&oly3000z_cam_desc},
 	{"Olympus", "C-3020Z", SIERRA_MODEL_CAM_DESC,  0x07b4, 0x105,
 					SIERRA_WRAP_USB, &oly3040_cam_desc},
 	{"Olympus", "C-3030Z", SIERRA_MODEL_CAM_DESC,	0x07b4, 0x100, 0,
@@ -722,12 +728,11 @@ put_file_func (CameraFilesystem * fs, const char *folder, CameraFile * file, voi
 }
 
 #ifdef UNUSED_CODE
-// FIXME: Is this function still usefull ?
 static void dump_register (Camera *camera, GPContext *context)
 {
 	int ret, value, i;
 	const char *description[] = {
-		"?",				//   0
+		"?",				/* 0 */
 		"resolution",
 		"date",
 		"shutter speed",
@@ -737,7 +742,7 @@ static void dump_register (Camera *camera, GPContext *context)
 		"flash mode",
 		"?",
 		"?",
-		"frames taken",			//  10
+		"frames taken",			/* 10 */
 		"frames left",
 		"size of current image",
 		"size of thumbnail of current image",
@@ -747,7 +752,7 @@ static void dump_register (Camera *camera, GPContext *context)
 		"?",
 		"?",
 		"brightness/contrast",
-		"white balance",		//  20
+		"white balance",		/* 20 */
 		"?",
 		"camera id",
 		"auto off (host)",
@@ -757,7 +762,7 @@ static void dump_register (Camera *camera, GPContext *context)
 		"?",
 		"memory left",
 		"?",
-		"?",				//  30
+		"?",				/* 30 */
 		"?",
 		"?",
 		"lens mode",
@@ -767,31 +772,31 @@ static void dump_register (Camera *camera, GPContext *context)
 		"?",
 		"lcd auto off",
 		"?",
-		"?",				//  40
+		"?",				/* 40 */
 		"?", "?", "?", "?", "?", "?", "?", "?", "?",
-		"?",				//  50
+		"?",				/* 50 */
 		"?", "?", "?", "?", "?", "?", "?", "?", "?",
-		"?",				//  60
+		"?",				/* 60 */
 		"?", "?", "?", "?", "?", "?", "?", "?", "?",
-		"spot metering mode",		//  70
+		"spot metering mode",		/* 70 */
 		"?",
 		"zoom",
 		"?", "?", "?", "?", "?", "?", 
 		"current filename",
-		"?",				//  80
+		"?",				/* 80 */
 		"?", "?",
 		"number of folders in current folder/folder number",
 		"current folder name",
 		"?", "?", "?", "?", "?",
-		"?",				//  90
+		"?",				/* 90 */
 		"?", "?", "?", "?", "?", "?", "?", "?", "?",
-		"?", 				// 100
+		"?", 				/* 100 */
 		"?", "?", "?", "?", "?", "?", "?", "?", "?",
-		"?", 				// 110
+		"?", 				/* 110 */
 		"?", "?", "?", "?", "?", "?", "?", "?", "?",
-		"?",				// 120
+		"?",				/* 120 */
 		"?", "?", "?", "?", "?", "?", "?", "?", "?",
-		"?"				// 130
+		"?"				/* 130 */
 	};
 		
 
@@ -895,9 +900,10 @@ camera_get_config_olympus (Camera *camera, CameraWidget **window, GPContext *con
 	/* Color Mode */
         ret = sierra_get_int_register (camera, 6, &value, context);
         if (ret >= 0) {
-
-		// Those values are for a C-2020 Z. If your model differs, we
-		// have to distinguish models here...
+		/*
+		 * Those values are for a C-2020 Z. If your model differs,
+		 * we have to distinguish models here.
+		 */
 		gp_widget_new (GP_WIDGET_RADIO, _("Color Mode"), &child);
 		gp_widget_add_choice (child, _("Normal"));
 		gp_widget_add_choice (child, _("Black/White"));
@@ -1811,7 +1817,6 @@ camera_set_config_epson (Camera *camera, CameraWidget *window, GPContext *contex
 static int
 camera_get_config_default (Camera *camera, CameraWidget **window, GPContext *context)
 {
-	// This really should change in the near future...
 	return camera_get_config_olympus (camera, window, context);
 }
 
@@ -1819,7 +1824,6 @@ camera_get_config_default (Camera *camera, CameraWidget **window, GPContext *con
 static int
 camera_set_config_default (Camera *camera, CameraWidget *window, GPContext *context)
 {
-	// This really should change in the near futur...
 	return camera_set_config_olympus (camera, window, context);
 }
 
@@ -1900,7 +1904,7 @@ camera_manual (Camera *camera, CameraText *manual, GPContext *context)
 		}
 		break;
 	case SIERRA_MODEL_EPSON:
-		strcpy (manual->text,
+		snprintf (manual->text, sizeof(manual->text),
 			_("Some notes about Epson cameras:\n"
 			  "- Some parameters are not controllable remotely:\n"
 			  "  * zoom\n"
@@ -1908,7 +1912,7 @@ camera_manual (Camera *camera, CameraText *manual, GPContext *context)
 			  "  * custom white balance setup\n"
 			  "- Configuration has been reverse-engineered with\n"
 			  "  a PhotoPC 3000z, if your camera acts differently\n"
-			  "  please send a mail to <gphoto-devel@lists.sourceforge.net> (in English)\n"));
+			  "  please send a mail to %s (in English)\n"), MAIL_GPHOTO_DEVEL);
 		break;
 	case SIERRA_MODEL_OLYMPUS:
 	default:
